﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Text;

namespace ExceptionPOC
{
	/// <summary>
	/// The String Extensions class.
	/// </summary>
	public static class StringExtensions
	{
		/// <summary>
		/// Determine if a string is not Null.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <returns>True if the string is not Null; False otherwise.</returns>
		public static bool IsNotNull(this string inString)
		{
			return inString != null;
		}

		/// <summary>
		/// Determine if a string is not Null or an empty string.
		/// A string of blanks will be treated as an empty string.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <returns>
		/// True if the string is not Null or an empty string; False otherwise.
		/// </returns>
		public static bool IsNotNullOrEmpty(this string inString)
		{
			return !inString.IsNullOrEmpty(true);
		}

		/// <summary>
		/// Determine if a string is not Null or an empty string.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <param name="trimToCheck">
		/// Should the string be trimmed before checking for empty string?
		/// If True, a string of blanks will be treated as an empty string.
		/// </param>
		/// <returns>
		/// True if the string is not Null or an empty string; False otherwise.
		/// </returns>
		public static bool IsNotNullOrEmpty(this string inString, bool trimToCheck)
		{
			return !inString.IsNullOrEmpty(trimToCheck);
		}

		/// <summary>
		/// Determine if a string is Null.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <returns>
		/// True if the string is not Null; False otherwise.
		/// </returns>
		public static bool IsNull(this string inString)
		{
			return inString == null;
		}

		/// <summary>
		/// Determine if a string is Null or is an empty string.
		/// A string of blanks will be treated as an empty string.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <returns>
		/// True if the string is Null or an empty string; False otherwise.
		/// </returns>
		public static bool IsNullOrEmpty(this string inString)
		{
			return inString.IsNullOrEmpty(true);
		}

		/// <summary>
		/// Determine if a string is Null or is an empty string.
		/// </summary>
		/// <param name="inString">The string to check.</param>
		/// <param name="trimToCheck">
		/// Should the string be trimmed before checking for empty string?
		/// If True, a string of blanks will be treated as an empty string.
		/// </param>
		/// <returns>
		/// True if the string is Null or an empty string; False otherwise.
		/// </returns>
		public static bool IsNullOrEmpty(this string inString, bool trimToCheck)
		{
			bool isNullOrEmpty = inString.IsNull();

			if (!isNullOrEmpty)
			{
				if (trimToCheck)
				{
					isNullOrEmpty = (inString.Trim() == String.Empty);
				}
				else
				{
					isNullOrEmpty = (inString == String.Empty);
				}
			}

			return isNullOrEmpty;
		}
	}
}
